"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.check = void 0;

var _glob = _interopRequireDefault(require("glob"));

var _path = _interopRequireDefault(require("path"));

var _eslint = require("eslint");

var _LintRunner = _interopRequireDefault(require("../LintRunner"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const check = async options => {
  const {
    workers,
    paths,
    formatter,
    ignored,
    rcPath,
    maxWarnings,
    quiet,
    fix
  } = options;
  const lintRunner = new _LintRunner.default(workers, !!quiet, fix);

  const rcDir = _path.default.dirname(rcPath);

  const eslint = new _eslint.ESLint({
    cwd: rcDir
  });
  const filePaths = (paths.map(globPath => _glob.default.sync(globPath, {
    cwd: rcDir,
    absolute: true,
    ignore: ignored
  })) || []).flat(); // filter out the files that we tell eslint to ignore

  const nonIgnoredFilePaths = (await Promise.all(filePaths.map(async filePath => {
    return (await eslint.isPathIgnored(filePath)) || filePath.indexOf("eslint") !== -1 ? null : filePath;
  }))).filter(Boolean);
  const results = await lintRunner.run(nonIgnoredFilePaths);
  const records = results.records.filter(record => {
    return record.warningCount > 0 || record.errorCount > 0;
  });
  const lintFormatter = await eslint.loadFormatter(formatter);
  console.log(lintFormatter.format(records));
  process.exit(results && (results.errorCount > 0 ? 1 : 0 || results.warningCount > maxWarnings ? 1 : 0));
};

exports.check = check;